@@ -32,11 +32,11 @@ __all__ = [
  'ConvertDataToHDF',
  'CreateAtomIndices',
  'FindPaths',
- 'Interactive-SCRE',
+ 'InteractiveSCRE',
  'PCCA',
  'PlotImpliedTimescales',
  'RebuildProject',
  'SampleTrajectory',
  'SaveStructures',
  'TrimAssignments',
- 'tICA_train']
\ No newline at end of file
+ 'tICA_train']
